import React from 'react'
import presets from '@/utils/globalPresets'
import Link from 'next/link'
import Image from 'next/image'

const generateStarStyle = () => {
  const size = Math.random() * 3 + 1
  return {
    width: `${size}px`,
    height: `${size}px`,
    borderRadius: '50%',
    background: 'white',
    position: 'absolute',
    top: `${Math.random() * 100}%`,
    left: `${Math.random() * 100}%`,
    animation: `blink ${Math.random() * 2 + 1}s infinite`
  }
}

const NotFound = () => {
  const stars = new Array(100).fill(0)

  return (
    <div className='relative z-10 -m-2 h-[90dvh] overflow-hidden bg-gradient-to-br from-purple-950 via-violet-950 to-blue-950'>
      <div className="absolute inset-0 z-[10]">
        {stars.map((_, index) => (
          <div key={index} style={generateStarStyle()} />
        ))}
      </div>

      <div className="relative z-[28] flex h-full flex-col justify-center bg-transparent text-center"
        style={{
          backgroundImage: `url(${process.env.publicPath}/images/404/overlay_stars.svg)`,
          backgroundRepeat: 'repeat',
          backgroundSize: 'contain',
          backgroundPosition: 'left top'
        }}
      >
        <h1 className="text-8xl font-extrabold tracking-widest text-violet-100">404</h1>
        <p className="text-balance text-xl text-purple-200">Parece que te has desviado de la órbita...</p>
        <p className="text-xl font-semibold text-purple-200">La página que buscas no existe.</p>
        <Link href={`${presets.locations.welcome}`}
          className="mt-5 inline-block">
          <button className="rounded bg-blue-700 px-5 py-3 text-lg text-white transition duration-300 hover:bg-blue-800">
            Navegar de Regreso
          </button>
        </Link>
      </div>

      <div className="">
        <Image
          style={{
            zIndex: 39,
            position: 'absolute',
            transform: 'translateX(-50px)',
            top: '75%',
            pointerEvents: 'none',
            animation: 'rocket-movement 200s linear infinite both running'
          }}
          src={`${process.env.publicPath}/images/404/rocket.svg`}
          width={60}
          height={60}
          alt='rocket'
        />
        <div className="">
          <Image className="absolute left-[15%] top-[20%] z-[35]"
            src={`${process.env.publicPath}/images/404/earth.svg`}
            width={100}
            height={100}
            alt='earth'
          />
          <Image
            style={{
              position: 'absolute',
              top: '12%',
              left: '25%',
              animation: 'orbit 120s infinite linear both'
            }}
            src={`${process.env.publicPath}/images/404/moon.svg`}
            width={80}
            height={80}
            alt='moon'
          />
        </div>
        <div
          style={{
            zIndex: 20,
            position: 'absolute',
            top: '60%',
            right: '20%',
            willChange: 'transform',
            animation: 'move-astronaut 50s infinite linear both alternate'
          }}
        >
          <Image
            style={{
              animation: 'rotate-astronaut 200s infinite linear both alternate'
            }}
            src={`${process.env.publicPath}/images/404/astronaut.svg`}
            width={140}
            height={140}
            alt='astronaut'
          />
        </div>
      </div>
    </div>
  )
}

export default NotFound
