import { RouteProvider } from '@/hooks/useRoute'
import { ThemeProvider } from '@/components/theme-provider'
import ResponsiveContainer from '@/layout/ResponsiveContainer'
import LoadingProvider from '@/plugins/LoadingContext'
import I18nProvider from '@/plugins/i18nContext'
import Head from 'next/head'

// Estilos globales
import '@/styles/globals.css'
import 'vComponents/styles/generated/output.css'

import { Portal } from '@headlessui/react'
import { ToastContainer } from 'react-toastify'
import presets from '@/utils/globalPresets'

export default function App ({ Component, pageProps }) {
  return (
    <>
      <Head>
        <link rel="icon" href="https://wiki.via-asesores.com/logo-orbis_min.png" type="image/x-icon" />
        <title>Orbis Template</title>
      </Head>

      <ThemeProvider
        attribute="class"
        defaultTheme="system"
        enableSystem
      >
        <I18nProvider locale={'es'} dict={''}>
          <LoadingProvider>
            <Portal>
              <ToastContainer
                {...presets.toaster}
                toastClassName={'rounded-lg bg-white text-black shadow-md dark:!bg-black dark:text-white'}
                style={{ zIndex: 99999 }}
              />
            </Portal>
            <ResponsiveContainer>
              <RouteProvider>
                <Component {...pageProps} />
              </RouteProvider>
            </ResponsiveContainer>
          </LoadingProvider>
        </I18nProvider>
      </ThemeProvider>
    </>
  )
}
